@@ -95,7 +95,7 @@ test! {
   ",
   args: ("--choose"),
   stdout: "",
-  stderr: "Justfile contains no choosable recipes.\n",
+  stderr: "error: Justfile contains no choosable recipes.\n",
   status: EXIT_FAILURE,
 }
 
@@ -113,9 +113,65 @@ test! {
   stderr: "echo foo\necho bar\n",
 }
 
+#[test]
+fn invoke_error_function() {
+  Test::new()
+    .justfile(
+      "
+        foo:
+          echo foo
+
+        bar:
+          echo bar
+      ",
+    )
+    .stderr(if cfg!(windows) {
+      "error: Chooser `/ -cu fzf` invocation failed: Access is denied. (os error 5)\n"
+    } else {
+      "error: Chooser `/ -cu fzf` invocation failed: Permission denied (os error 13)\n"
+    })
+    .status(EXIT_FAILURE)
+    .shell(false)
+    .args(&["--shell", "/", "--choose"])
+    .run();
+}
+
+#[test]
+#[cfg(not(windows))]
+fn status_error() {
+  let tmp = temptree! {
+    justfile: "foo:\n echo foo\nbar:\n echo bar\n",
+    "exit-2": "#!/usr/bin/env bash\nexit 2\n",
+  };
+
+  ("chmod", "+x", tmp.path().join("exit-2")).run();
+
+  let path = env::join_paths(
+    iter::once(tmp.path().to_owned()).chain(env::split_paths(&env::var_os("PATH").unwrap())),
+  )
+  .unwrap();
+
+  let output = Command::new(executable_path("just"))
+    .current_dir(tmp.path())
+    .arg("--choose")
+    .arg("--chooser")
+    .arg("exit-2")
+    .env("PATH", path)
+    .output()
+    .unwrap();
+
+  assert!(
+    Regex::new("^error: Chooser `exit-2` failed: exit (code|status): 2\n$")
+      .unwrap()
+      .is_match(str::from_utf8(&output.stderr).unwrap())
+  );
+
+  assert_eq!(output.status.code().unwrap(), 2);
+}
+
 #[test]
 fn default() {
-  let tmp = tmptree! {
+  let tmp = temptree! {
     justfile: "foo:\n echo foo\n",
   };
 
